==> vst3sdk-docs-3.7.13_build_42-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstgui/html/group__new__in__4__5.js <==
var group__new__in__4__5 =
[
    [ "VSTGUI::Standalone", "namespace_v_s_t_g_u_i_1_1_standalone.html", null ],
    [ "IFocusViewObserver", "class_v_s_t_g_u_i_1_1_i_focus_view_observer.html", [
      [ "~IFocusViewObserver", "class_v_s_t_g_u_i_1_1_i_focus_view_observer.html#a8a590ad290d990d4a460a2c76f5884f9", null ],
      [ "onFocusViewChanged", "class_v_s_t_g_u_i_1_1_i_focus_view_observer.html#a0660c225c80b41533cf0c4b7a62b9c6b", null ]
    ] ],
    [ "CSearchTextEdit", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html", [
      [ "CSearchTextEdit", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#a8181b5860d9e605275ce1de4083d3935", null ],
      [ "draw", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#a2223292a91c85ab8ff9d156763543bf2", null ],
      [ "drawClearMark", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#a8ba7e335b4d10fbd4f9fb5f3c19b13db", null ],
      [ "getClearMarkInset", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#ab8b40db3a6e4b85d41acbe7d1218dfb9", null ],
      [ "getClearMarkRect", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#a077449921d48c1fb86255d6c494c7671", null ],
      [ "getTextRect", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#ad8f21293405486e840ddb42dc7b3ce3f", null ],
      [ "onMouseDown", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#a5dd3200e872b6337fa6eefe9599dd596", null ],
      [ "platformGetSize", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#a63bfc19c5f213f62e34ab4fd115ec48f", null ],
      [ "platformGetVisibleSize", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#a53c758da24791961844978a06f7a762d", null ],
      [ "platformTextDidChange", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#a1df0665ccbb8389faab9f30702c59503", null ],
      [ "setClearMarkInset", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#ae0b6a5b714bf7f5f11e88047a7527841", null ],
      [ "clearMarkInset", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#acb22c54b20bf673c692095a6875466f8", null ]
    ] ],
    [ "CMultiLineTextLabel", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html", [
      [ "LineLayout", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#ad81036e8258f64a56ffda6c90a6ad03a", [
        [ "clip", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#ad81036e8258f64a56ffda6c90a6ad03aaf6d8b886335927d46fad323c60335d09", null ],
        [ "truncate", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#ad81036e8258f64a56ffda6c90a6ad03aa244f58cf07c35fd48d7524b289551e5c", null ],
        [ "wrap", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#ad81036e8258f64a56ffda6c90a6ad03aaccfc59a528a109fa4204e8ea06e8b68b", null ]
      ] ],
      [ "CMultiLineTextLabel", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a3d040f028c7ab4397d2a0c4c4a1cad41", null ],
      [ "CMultiLineTextLabel", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a5ad3e027e43e7823f7bc650c40c48a5e", null ],
      [ "drawRect", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#ac3627a2e2abcfe4e6df2a77e4829446a", null ],
      [ "getAutoHeight", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#aa38cf6cff49d139658a0f296f34ee91a", null ],
      [ "getLineLayout", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a6412c077a54ec8fe74f9dd0f6ff0dd4c", null ],
      [ "getMaxLineWidth", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a1c81a33e0d1a00d9c06fe6489c1483fb", null ],
      [ "getVerticalCentered", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#afe57a067017c8a9a8c283dffdc273542", null ],
      [ "setAutoHeight", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a13057bfdab11b70b71d55267673c127a", null ],
      [ "setLineLayout", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a1d97d7fb8526b064bed9f9b7c4670cdf", null ],
      [ "setText", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a8d129b929c302f7ba76699c7fc1a1310", null ],
      [ "setTextTruncateMode", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a9c566d0c36fd72e055191281e662a344", null ],
      [ "setValue", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a26104ef97e1ebbc08e948bd1b98704cc", null ],
      [ "setVerticalCentered", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a01a0f213779802ce59247485e504388d", null ],
      [ "setViewSize", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#afa3d86320cb051cecb3c687a523ba787", null ],
      [ "sizeToFit", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a64c95c189130160521d50820d9982242", null ]
    ] ],
    [ "Optional< T >", "struct_v_s_t_g_u_i_1_1_optional.html", [
      [ "Optional", "struct_v_s_t_g_u_i_1_1_optional.html#abaacb7a82cc19d22b6ef512422dd860c", null ],
      [ "Optional", "struct_v_s_t_g_u_i_1_1_optional.html#afe4a4fd73032ccb8333adc78c8d885be", null ],
      [ "Optional", "struct_v_s_t_g_u_i_1_1_optional.html#a8abdf29c53e2d866ae58f1550b479120", null ],
      [ "Optional", "struct_v_s_t_g_u_i_1_1_optional.html#a69aab7db725675c63350cc385b5c82f2", null ],
      [ "Optional", "struct_v_s_t_g_u_i_1_1_optional.html#af9e0e7333b5326d69a50cf183c946d4e", null ],
      [ "operator bool", "struct_v_s_t_g_u_i_1_1_optional.html#a67b76affb3b5d35fa419ac234144038b", null ],
      [ "operator*", "struct_v_s_t_g_u_i_1_1_optional.html#aef577cb229ef2a9d16ea231ab32bb90d", null ],
      [ "operator*", "struct_v_s_t_g_u_i_1_1_optional.html#a2a9f29ac7023ba40dd75b9ba44aeafa0", null ],
      [ "operator->", "struct_v_s_t_g_u_i_1_1_optional.html#a4442b1b9eab40e7939e1e01cdedcb7ae", null ],
      [ "operator->", "struct_v_s_t_g_u_i_1_1_optional.html#abaade5c780b539b94de660e314cb0c90", null ],
      [ "operator=", "struct_v_s_t_g_u_i_1_1_optional.html#a53fb5001ff46d9a9f7614c898642a201", null ],
      [ "operator=", "struct_v_s_t_g_u_i_1_1_optional.html#a98472d7045aa81ce6184748058075986", null ],
      [ "reset", "struct_v_s_t_g_u_i_1_1_optional.html#ad20897c5c8bd47f5d4005989bead0e55", null ],
      [ "value", "struct_v_s_t_g_u_i_1_1_optional.html#aae152174cdc97c454fcfc5f106f41d4d", null ],
      [ "value", "struct_v_s_t_g_u_i_1_1_optional.html#ab5d906b55180c260032ce43d6c5d4d06", null ]
    ] ]
];

==> vst3sdk-docs-3.8.0_build_66-1-any.pkg.tar.zst: usr/share/doc/vst3sdk-docs/vstgui/html/group__new__in__4__5.js <==
var group__new__in__4__5 =
[
    [ "Standalone", "namespace_v_s_t_g_u_i_1_1_standalone.html", null ],
    [ "IFocusViewObserver", "class_v_s_t_g_u_i_1_1_i_focus_view_observer.html", [
      [ "~IFocusViewObserver", "class_v_s_t_g_u_i_1_1_i_focus_view_observer.html#a8a590ad290d990d4a460a2c76f5884f9", null ],
      [ "onFocusViewChanged", "class_v_s_t_g_u_i_1_1_i_focus_view_observer.html#a0660c225c80b41533cf0c4b7a62b9c6b", null ]
    ] ],
    [ "CSearchTextEdit", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html", [
      [ "CSearchTextEdit", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#a8181b5860d9e605275ce1de4083d3935", null ],
      [ "draw", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#a2223292a91c85ab8ff9d156763543bf2", null ],
      [ "drawClearMark", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#a8ba7e335b4d10fbd4f9fb5f3c19b13db", null ],
      [ "getClearMarkInset", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#ab8b40db3a6e4b85d41acbe7d1218dfb9", null ],
      [ "getClearMarkRect", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#a077449921d48c1fb86255d6c494c7671", null ],
      [ "getTextRect", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#ad8f21293405486e840ddb42dc7b3ce3f", null ],
      [ "onMouseDown", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#a5dd3200e872b6337fa6eefe9599dd596", null ],
      [ "platformGetSize", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#a63bfc19c5f213f62e34ab4fd115ec48f", null ],
      [ "platformGetVisibleSize", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#a53c758da24791961844978a06f7a762d", null ],
      [ "platformTextDidChange", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#a1df0665ccbb8389faab9f30702c59503", null ],
      [ "setClearMarkInset", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#ae0b6a5b714bf7f5f11e88047a7527841", null ],
      [ "clearMarkInset", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html#acb22c54b20bf673c692095a6875466f8", null ]
    ] ],
    [ "CMultiLineTextLabel", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html", [
      [ "LineLayout", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#ad81036e8258f64a56ffda6c90a6ad03a", [
        [ "clip", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#ad81036e8258f64a56ffda6c90a6ad03aaf6d8b886335927d46fad323c60335d09", null ],
        [ "truncate", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#ad81036e8258f64a56ffda6c90a6ad03aa244f58cf07c35fd48d7524b289551e5c", null ],
        [ "wrap", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#ad81036e8258f64a56ffda6c90a6ad03aaccfc59a528a109fa4204e8ea06e8b68b", null ]
      ] ],
      [ "CMultiLineTextLabel", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a3d040f028c7ab4397d2a0c4c4a1cad41", null ],
      [ "CMultiLineTextLabel", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a5ad3e027e43e7823f7bc650c40c48a5e", null ],
      [ "drawRect", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#ac3627a2e2abcfe4e6df2a77e4829446a", null ],
      [ "getAutoHeight", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#aa38cf6cff49d139658a0f296f34ee91a", null ],
      [ "getLineLayout", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a6412c077a54ec8fe74f9dd0f6ff0dd4c", null ],
      [ "getMaxLineWidth", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a1c81a33e0d1a00d9c06fe6489c1483fb", null ],
      [ "getVerticalCentered", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#afe57a067017c8a9a8c283dffdc273542", null ],
      [ "setAutoHeight", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a13057bfdab11b70b71d55267673c127a", null ],
      [ "setLineLayout", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a1d97d7fb8526b064bed9f9b7c4670cdf", null ],
      [ "setText", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a8d129b929c302f7ba76699c7fc1a1310", null ],
      [ "setTextTruncateMode", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a9c566d0c36fd72e055191281e662a344", null ],
      [ "setValue", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a26104ef97e1ebbc08e948bd1b98704cc", null ],
      [ "setVerticalCentered", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a01a0f213779802ce59247485e504388d", null ],
      [ "setViewSize", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#afa3d86320cb051cecb3c687a523ba787", null ],
      [ "sizeToFit", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html#a64c95c189130160521d50820d9982242", null ]
    ] ],
    [ "Optional< T >", "struct_v_s_t_g_u_i_1_1_optional.html", [
      [ "Optional", "struct_v_s_t_g_u_i_1_1_optional.html#abaacb7a82cc19d22b6ef512422dd860c", null ],
      [ "Optional", "struct_v_s_t_g_u_i_1_1_optional.html#afe4a4fd73032ccb8333adc78c8d885be", null ],
      [ "Optional", "struct_v_s_t_g_u_i_1_1_optional.html#a8abdf29c53e2d866ae58f1550b479120", null ],
      [ "Optional", "struct_v_s_t_g_u_i_1_1_optional.html#a69aab7db725675c63350cc385b5c82f2", null ],
      [ "Optional", "struct_v_s_t_g_u_i_1_1_optional.html#af9e0e7333b5326d69a50cf183c946d4e", null ],
      [ "operator bool", "struct_v_s_t_g_u_i_1_1_optional.html#a67b76affb3b5d35fa419ac234144038b", null ],
      [ "operator*", "struct_v_s_t_g_u_i_1_1_optional.html#aef577cb229ef2a9d16ea231ab32bb90d", null ],
      [ "operator*", "struct_v_s_t_g_u_i_1_1_optional.html#a2a9f29ac7023ba40dd75b9ba44aeafa0", null ],
      [ "operator->", "struct_v_s_t_g_u_i_1_1_optional.html#a4442b1b9eab40e7939e1e01cdedcb7ae", null ],
      [ "operator->", "struct_v_s_t_g_u_i_1_1_optional.html#abaade5c780b539b94de660e314cb0c90", null ],
      [ "operator=", "struct_v_s_t_g_u_i_1_1_optional.html#a53fb5001ff46d9a9f7614c898642a201", null ],
      [ "operator=", "struct_v_s_t_g_u_i_1_1_optional.html#a98472d7045aa81ce6184748058075986", null ],
      [ "reset", "struct_v_s_t_g_u_i_1_1_optional.html#ad20897c5c8bd47f5d4005989bead0e55", null ],
      [ "value", "struct_v_s_t_g_u_i_1_1_optional.html#aae152174cdc97c454fcfc5f106f41d4d", null ],
      [ "value", "struct_v_s_t_g_u_i_1_1_optional.html#ab5d906b55180c260032ce43d6c5d4d06", null ]
    ] ]
];
